
__version__ = "0.7"
__version_vcs_info__ = {
    'branch': 'master',
    'revid': 'ab4d13b',
    'revno': 571}
__version_user_email__ = "skalkoto@grnet.gr"
__version_user_name__ = "Nikos Skalkotos"
